# diagnosticism.Python
diagnosticism library, for Python

## Table of Contents

1. [Introduction](#introduction)
2. [Installation](#installation)
3. [Components](#components)
4. [Examples](#examples)
5. [Project Information](#project-information)

## Introduction

T.B.C.

## Installation & usage

Install via **pip** or **pip3**, as in:

```
	pip3 install diagnosticism
```

Use via **import**:

```Python

import diagnosticism
```

## Components

T.B.C.

## Examples

Examples are provided in the ```examples``` directory, along with a markdown description for each. A detailed list TOC of them is provided in [EXAMPLES.md](./EXAMPLES.md).

## Project Information

### Where to get help

[GitHub Page](https://github.com/synesissoftware/diagnosticism.Python "GitHub Page")

### Contribution guidelines

Defect reports, feature requests, and pull requests are welcome on https://github.com/synesissoftware/diagnosticism.Python.

### Dependencies

### Related projects

* [**diagnosticism.Go**](https://github.com/synesissoftware/diagnosticism.Go/)
* [**diagnosticism.NET**](https://github.com/synesissoftware/diagnosticism.NET/)

### License

**diagnosticism.Python** is released under the 3-clause BSD license. See [LICENSE](./LICENSE) for details.

